@@ -1,4 +1,5 @@
 from . import util
+from .exceptions import KrankshaftError
 from .query import DjangoQuery
 from django.core.urlresolvers import reverse
 from django.db import models
@@ -8,6 +9,16 @@ try:
 except ImportError:
     from .compat.xact import xact as atomic
 
+# TODO serialize file fields...
+#   field: 'upload_to/file...',
+#   field_href: '/media/upload_to/file...',
+#
+#   how to update that field?
+#   should we strip upload_to?
+#   we don't want to expose the upload_to path because that's a server side
+#   setting... right?
+#   maybe it doesnt matter...
+#   how do we handle upload? just ignore the field?
 class DjangoModelResource(object):
     '''
     Expose a Django Model as a RESTful resource.  Default implementation
@@ -51,6 +62,7 @@ class DjangoModelResource(object):
                         see version_field caveat
 
     '''
+    Error = KrankshaftError
     Query = DjangoQuery
     allowed_methods = None
     allowed_methods_endpoint = None
@@ -77,6 +89,9 @@ class DjangoModelResource(object):
                 if field.name not in self.excludes
             ])
 
+        if hasattr(self, 'exclude'):
+            raise self.Error('You probably meant to use "excludes"')
+
         self.expected = {}
         self.expected_pk = None
         self.loaded = False
